==> zhongyan-activity-service-api-2.0.25.1-20230517.111653-1-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/PrizeConditionParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.io.Serializable;

/**
 * @author LuHui
 * @description
 * @date 2021/11/27  18:41
 */
public class PrizeConditionParam implements Serializable {

    private static final long serialVersionUID = 3003129481666459388L;
    /**
     * 页码
     */
    private Integer pageIndex;

    /**
     * 页容量
     */
    private Integer pageSize;

    /**
     * 奖品状态 0 全部 1:待领奖 2:已领奖 3:已失效
     */
    private Integer status;

    /**
     * 用户id
     */
    private Long userId;

    /**
     * 活动ID
     */
    private Long activityId;

    /**
     * openId
     */
    private String openId;

    /**
     * unionId
     */
    private String unionId;

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public Integer getPageIndex() {
        return pageIndex;
    }

    public void setPageIndex(Integer pageIndex) {
        this.pageIndex = pageIndex;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }


    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
}

==> zhongyan-activity-service-api-2.0.26-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/PrizeConditionParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author LuHui
 * @description
 * @date 2021/11/27  18:41
 */
public class PrizeConditionParam implements Serializable {

    private static final long serialVersionUID = 3003129481666459388L;
    /**
     * 页码
     */
    private Integer pageIndex;

    /**
     * 页容量
     */
    private Integer pageSize;

    /**
     * 奖品状态 0 全部 1:待领奖 2:已领奖 3:已失效
     */
    private Integer status;

    /**
     * 用户id
     */
    private Long userId;
    /**
     * 开始时间
     */
    private Date beginTime;
    /**
     * 结束时间
     */
    private Date endTime;

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getPageIndex() {
        return pageIndex;
    }

    public void setPageIndex(Integer pageIndex) {
        this.pageIndex = pageIndex;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }


    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
}
